import cgi

from paste.urlparser import PkgResourcesParser
from pylons import request, config
from pylons.controllers.util import forward
from webhelpers.html.builder import literal

from mpulsweb.lib.base import BaseController, render, c


class ErrorController(BaseController):

    """Generates error documents as and when they are required.

    The ErrorDocuments middleware forwards to ErrorController when error
    related status codes are returned from the application.

    This behaviour can be altered by changing the parameters to the
    ErrorDocuments middleware in your config/middleware.py file.

    """

    def document(self):
        """Render the error document"""
        resp = request.environ.get('pylons.original_response')
        c.error_code = cgi.escape(request.GET.get('code', str(resp.status_int)))
        c.error_message = (literal(resp.body)
                           or cgi.escape(request.GET.get('message', '')))
        c.error_email = config.get('email_to', 'mpuls@intevation.de')
        return render('/error/error.mako')

    def img(self, id):
        """Serve Pylons' stock images"""
        return self._serve_file('/'.join(['media/img', id]))

    def style(self, id):
        """Serve Pylons' stock stylesheets"""
        return self._serve_file('/'.join(['media/style', id]))

    def _serve_file(self, path):
        """Call Paste's FileApp (a WSGI application) to serve the file
        at the specified path
        """
        request.environ['PATH_INFO'] = '/%s' % path
        return forward(PkgResourcesParser('pylons', 'pylons'))
