import logging

from pylons import tmpl_context as c, app_globals as g

from mpulsweb.model.news import NewsList
from mpulsweb.model.appointment import GlobalAppointmentOverview, \
     CaseAppointmentOverview, MaxSaveTimeReminderOverview, CaseReminderOverview
from mpulsweb.lib.base import BaseController, render, session
import mpulsweb.lib.helpers as h


log = logging.getLogger(__name__)


class MpulsController(BaseController):

    def index(self):
        user = session['USER_AUTHORIZED']

        # LOAD NEWS
        if g.mpuls_config.is_enabled('module', 'news'):
            log.debug('Loading news list')
            c.news = self.get_newslist(user)

        # LOAD APPOINTMENTS
        if g.mpuls_config.is_enabled('case-module', 'appointments'):
            # Case appointments
            log.debug('Loading case appointment list')
            c.appointmentlist = self.get_case_appointments()
        if g.mpuls_config.is_enabled('case-module', 'reminders'):
            # Case reminders
            log.debug('Loading reminders list')
            c.remindlist = self.get_reminders()
        if g.mpuls_config.is_enabled('module', 'appointments'):
            # Global appointments
            log.debug('Loading global appointment list')
            c.globalappointmentlist = self.get_global_appointments()

        return render('/home/home.mako')

    def get_newslist(self, user):
        """ Return an agency wide newslist """
        
        return NewsList(user)

    def get_global_appointments(self):
        """ Return agency wide appointments """
        
        return GlobalAppointmentOverview()

    def get_case_appointments(self):
        """ Return the user's appointments and reminders """
        
        appointment_list = CaseAppointmentOverview()
        if h.hasRole(['cm']):
            appointment_list.join(CaseReminderOverview())
            appointment_list.sort()
        return appointment_list

    def get_reminders(self):
        """Return an AppointmentOverview instance with reminders.
        The overview always contains the max save time reminders.
        """
        
        remindlist = MaxSaveTimeReminderOverview()
        remindlist.sort()
        return remindlist


