#!/usr/bin/env python

import psycopg2 as dbapi

import sys
import getopt

try:
    import sqlite3 as db
except ImportError:
    from pysqlite2 import dbapi2 as db

from itertools import izip

SELECT = '''SELECT * FROM master_tbl_anonym_view'''

SELECT_MAX_ID = '''SELECT coalesce(max(id), -1) FROM %(relation)s'''

INSERT_STMT = '''INSERT INTO master_tbl (%(fields)s) VALUES (%(placeholders)s)'''

SELECT_FKZ = "SELECT id, database FROM fkz_tbl"

SELECT_STATUS = "SELECT status, zugriff FROM ka_status_tbl WHERE id = %(id)s"

INSERT_STATUS = '''
INSERT INTO ka_status_tbl (id, master_id, status, zugriff)
       VALUES (:id, :master_id, :status, :zugriff)'''

SELECT_KOMPETENZ = '''SELECT %s FROM master_tbl_anonym_view WHERE id = %%(id)s'''
INSERT_KOMPETENZ = '''INSERT INTO rg_kompetenz_tbl (%(fields)s) VALUES (%(values)s)'''

ANON_TRANSFER = "SELECT wert = 'on' FROM ka_konfiguration_tbl WHERE bez = 'anon_transfer'"

def get_max_id(cur, relation):
    stmt = SELECT_MAX_ID % { 'relation': relation }
    cur.execute(stmt)
    row = cur.fetchone()
    if not row: return -1
    return row[0]

def usage(msg = "", exit_code = 0):
    print >> sys.stderr, """%s
usage:
%s -o <dump.db>
""" % (msg, sys.argv[0])
    sys.exit(exit_code)

BLACK_LIST = set([
    'id',
    'uuid_id',
    "addresse1_telefonnummer_1",
    "addresse1_vorwahl_1",
    "addresse2_telefonnummer_2",
    "addresse2_vorwahl_1",
    "addresse_email_1",
    "addresse_ort_1",
    "addresse_plz_1",
    "addresse_strasse_1",
    "addresse_strassenr_1",
    "addresse_weiteretelefonnummern",
    "addresse_weiteretelefonnummern_1",
    "bezugs_email_1",
    "bezugs_name_1",
    "bezugs_telefonnummer_1",
    "bezugs_vorname_1",
    "bezugs_vorwahl_1",
    "datum_kf_1",
    "dok_entw",
    "dok_nbetr",
    "entw_a_1",
    "entw_b_1",
    "entw_beh",
    "entw_c_1",
    "entw_d_1",
    "entw_e_1",
    "entw_f_1",
    "entw_g_1",
    "entw_h_1",
    "entw_h_t_1",
    "entw_i_1",
    "entw_i_t_1",
    "entw_j_1",
    "entw_j_t_1",
    "entw_k_1",
    "entw_k_t_1",
    "fehlfust_1",
    "fehlfust_10",
    "fehlfust_11",
    "fehlfust_12",
    "fehlfust_13",
    "fehlfust_14",
    "fehlfust_15",
    "fehlfust_16",
    "fehlfust_17",
    "fehlfust_18",
    "fehlfust_2",
    "fehlfust_3",
    "fehlfust_4",
    "fehlfust_5",
    "fehlfust_6",
    "fehlfust_7",
    "fehlfust_8",
    "fehlfust_9",
    "fehlj_1",
    "fehlj_10",
    "fehlj_11",
    "fehlj_12",
    "fehlj_13",
    "fehlj_14",
    "fehlj_15",
    "fehlj_16",
    "fehlj_17",
    "fehlj_18",
    "fehlj_2",
    "fehlj_3",
    "fehlj_4",
    "fehlj_5",
    "fehlj_6",
    "fehlj_7",
    "fehlj_8",
    "fehlj_9",
    "fehlm_1",
    "fehlm_10",
    "fehlm_11",
    "fehlm_12",
    "fehlm_13",
    "fehlm_14",
    "fehlm_15",
    "fehlm_16",
    "fehlm_17",
    "fehlm_18",
    "fehlm_2",
    "fehlm_3",
    "fehlm_4",
    "fehlm_5",
    "fehlm_6",
    "fehlm_7",
    "fehlm_8",
    "fehlm_9",
    "fehlst_1",
    "fehlst_10",
    "fehlst_11",
    "fehlst_12",
    "fehlst_13",
    "fehlst_14",
    "fehlst_15",
    "fehlst_16",
    "fehlst_17",
    "fehlst_18",
    "fehlst_2",
    "fehlst_3",
    "fehlst_4",
    "fehlst_5",
    "fehlst_6",
    "fehlst_7",
    "fehlst_8",
    "fehlst_9",
    "fehltg_1",
    "fehltg_10",
    "fehltg_11",
    "fehltg_12",
    "fehltg_13",
    "fehltg_14",
    "fehltg_15",
    "fehltg_16",
    "fehltg_17",
    "fehltg_18",
    "fehltg_2",
    "fehltg_3",
    "fehltg_4",
    "fehltg_5",
    "fehltg_6",
    "fehltg_7",
    "fehltg_8",
    "fehltg_9",
    "fehlutg_1",
    "fehlutg_10",
    "fehlutg_11",
    "fehlutg_12",
    "fehlutg_13",
    "fehlutg_14",
    "fehlutg_15",
    "fehlutg_16",
    "fehlutg_17",
    "fehlutg_18",
    "fehlutg_2",
    "fehlutg_3",
    "fehlutg_4",
    "fehlutg_5",
    "fehlutg_6",
    "fehlutg_7",
    "fehlutg_8",
    "fehlutg_9",
    "hilfm_1",
    "hilfm_2",
    "hilfm_3",
    "hilfm_art_1",
    "hilfm_art_2",
    "hilfm_art_3",
    "hilfm_einr_1",
    "hilfm_einr_2",
    "hilfm_einr_3",
    "hilfm_ende_1",
    "hilfm_ende_2",
    "hilfm_ende_3",
    "hilfm_erreicht_1_1",
    "hilfm_erreicht_1_2",
    "hilfm_erreicht_1_3",
    "hilfm_erreicht_2_1",
    "hilfm_erreicht_2_2",
    "hilfm_erreicht_2_3",
    "hilfm_erreicht_3_1",
    "hilfm_erreicht_3_2",
    "hilfm_erreicht_3_3",
    "hilfm_inst_1",
    "hilfm_inst_2",
    "hilfm_inst_3",
    "hilfm_sf_1",
    "hilfm_sf_2",
    "hilfm_sf_3",
    "hilfm_start_1",
    "hilfm_start_2",
    "hilfm_start_3",
    "hilfm_umf_1",
    "hilfm_umf_2",
    "hilfm_umf_3",
    "hilfm_zeit_1_1",
    "hilfm_zeit_1_2",
    "hilfm_zeit_1_3",
    "hilfm_zeit_2_1",
    "hilfm_zeit_2_2",
    "hilfm_zeit_2_3",
    "hilfm_zeit_3_1",
    "hilfm_zeit_3_2",
    "hilfm_zeit_3_3",
    "hilfm_ziel_1_1",
    "hilfm_ziel_1_2",
    "hilfm_ziel_1_3",
    "hilfm_ziel_2_1",
    "hilfm_ziel_2_2",
    "hilfm_ziel_2_3",
    "hilfm_ziel_3_1",
    "hilfm_ziel_3_2",
    "hilfm_ziel_3_3",
    "kd_bezug_1_telefon",
    "kd_bezug_1_vorwahl",
    "kd_bezug_2_telefon",
    "kd_bezug_2_vorwahl",
    "kd_bezug_3_telefon",
    "kd_bezug_3_vorwahl",
    "kd_bezug_email_1",
    "kd_bezug_email_2",
    "kd_bezug_email_3",
    "kd_bezug_funktion_1",
    "kd_bezug_funktion_2",
    "kd_bezug_funktion_3",
    "kd_bezug_name_1",
    "kd_bezug_name_2",
    "kd_bezug_name_3",
    "kd_bezug_ort_1",
    "kd_bezug_ort_2",
    "kd_bezug_ort_3",
    "kd_bezug_plz_1",
    "kd_bezug_plz_2",
    "kd_bezug_plz_3",
    "kd_bezug_strasse_1",
    "kd_bezug_strasse_2",
    "kd_bezug_strasse_3",
    "kd_bezug_strassenr_1",
    "kd_bezug_strassenr_2",
    "kd_bezug_strassenr_3",
    "kd_bezug_vorname_1",
    "kd_bezug_vorname_2",
    "kd_bezug_vorname_3",
    "kd_institution_email_1",
    "kd_institution_email_2",
    "kd_institution_email_3",
    "kd_institution_kundennummer_1",
    "kd_institution_kundennummer_2",
    "kd_institution_kundennummer_3",
    "kd_institution_name_1",
    "kd_institution_name_2",
    "kd_institution_name_3",
    "kd_institution_ort_1",
    "kd_institution_ort_2",
    "kd_institution_ort_3",
    "kd_institution_plz_1",
    "kd_institution_plz_2",
    "kd_institution_plz_3",
    "kd_institution_strasse_1",
    "kd_institution_strasse_2",
    "kd_institution_strasse_3",
    "kd_institution_strassenr_1",
    "kd_institution_strassenr_2",
    "kd_institution_strassenr_3",
    "kd_institution_telefonnummer_1",
    "kd_institution_telefonnummer_2",
    "kd_institution_telefonnummer_3",
    "kd_institution_vorwahl_1",
    "kd_institution_vorwahl_2",
    "kd_institution_vorwahl_3",
    "kd_jugendamt_email_1",
    "kd_jugendamt_kundennummer_1",
    "kd_jugendamt_ort_1",
    "kd_jugendamt_plz_1",
    "kd_jugendamt_strasse_1",
    "kd_jugendamt_strassenr_1",
    "kd_jugendamt_telefonnummer_1",
    "kd_jugendamt_vorwahl_1",
    "kd_schule_email_1",
    "kd_schule_name_1",
    "kd_schule_ort_1",
    "kd_schule_plz_1",
    "kd_schule_strasse_1",
    "kd_schule_strassenr_1",
    "kd_schule_telefonnummer_1",
    "kd_schule_vorwahl_1",
    "kf_anbiet_1",
    "kf_meth_a_1",
    "kf_meth_b_1",
    "kf_meth_d_1",
    "kf_meth_e_1",
    "kf_meth_f_1",
    "kf_meth_f_t_1",
    "kf_test_a_1",
    "kf_test_a_t_1",
    "kf_test_b_1",
    "kf_test_b_t_1",
    "kf_test_c_1",
    "kf_test_c_t_1",
    "kf_test_d_1",
    "kf_test_d_t_1",
    "kf_verfahren_1",
    "komp_anm",
    "komp_deutsch_a_1",
    "komp_deutsch_b_1",
    "komp_deutsch_c_1",
    "komp_deutsch_d_1",
    "komp_herkunft_1",
    "komp_psy_a_1",
    "komp_psy_b_1",
    "komp_psy_c_1",
    "komp_psy_d_1",
    "komp_psy_e_1",
    "komp_psy_f_1",
    "komp_psy_g_1",
    "komp_psy_g_t_1",
    "komp_schule_a_1",
    "komp_schule_b_1",
    "komp_schule_c_1",
    "komp_schule_d_1",
    "komp_schule_e_1",
    "komp_schule_f_1",
    "komp_schule_g_1",
    "komp_schule_g_t_1",
    "komp_selbst_a_1",
    "komp_selbst_b_1",
    "komp_selbst_c_1",
    "komp_selbst_d_1",
    "komp_selbst_e_1",
    "komp_selbst_f_1",
    "komp_selbst_g_1",
    "komp_selbst_g_t_1",
    "komp_sozial_a_1",
    "komp_sozial_b_1",
    "komp_sozial_c_1",
    "komp_sozial_d_1",
    "komp_sozial_e_1",
    "komp_sozial_f_1",
    "komp_sozial_g_1",
    "komp_sozial_g_t_1",
    "mutter_email_1",
    "mutter_ort_1",
    "mutter_plz_1",
    "mutter_strasse_1",
    "mutter_strassenr_1",
    "mutter_telefonnummer1_1",
    "mutter_telefonnummer2_1",
    "mutter_vorwahl1_1",
    "mutter_vorwahl2_1",
    "vater_email_1",
    "vater_ort_1",
    "vater_plz_1",
    "vater_strasse_1",
    "vater_strassenr_1",
    "vater_telefonnummer1_1",
    "vater_telefonnummer2_1",
    "vater_vorwahl1_1",
    "vater_vorwahl2_1"
])

KOMPETENZ_FESTSTELLUNG = {
    "datum_kf_1"       : "datum_kf",
    "kf_verfahren_1"   : "kf_verfahren",
    "kf_anbiet_1"      : "kf_anbiet",
    "kf_meth_a_1"      : "kf_meth_a",
    "kf_meth_b_1"      : "kf_meth_b",
    "kf_meth_d_1"      : "kf_meth_d",
    "kf_meth_e_1"      : "kf_meth_e",
    "kf_meth_f_1"      : "kf_meth_f",
    "kf_meth_f_t_1"    : "kf_meth_f_t",
    "kf_test_a_1"      : "kf_test_a",
    "kf_test_a_t_1"    : "kf_test_a_t",
    "kf_test_b_1"      : "kf_test_b",
    "kf_test_b_t_1"    : "kf_test_b_t",
    "kf_test_c_1"      : "kf_test_c",
    "kf_test_c_t_1"    : "kf_test_c_t",
    "kf_test_d_1"      : "kf_test_d",
    "kf_test_d_t_1"    : "kf_test_d_t",
    "komp_schule_a_1"  : "komp_schule_a",
    "komp_schule_b_1"  : "komp_schule_b",
    "komp_schule_c_1"  : "komp_schule_c",
    "komp_schule_d_1"  : "komp_schule_d",
    "komp_schule_e_1"  : "komp_schule_e",
    "komp_schule_f_1"  : "komp_schule_f",
    "komp_schule_g_1"  : "komp_schule_g",
    "komp_schule_g_t_1": "komp_schule_g_t",
    "komp_deutsch_a_1" : "komp_deutsch_a",
    "komp_deutsch_b_1" : "komp_deutsch_b",
    "komp_deutsch_c_1" : "komp_deutsch_c",
    "komp_deutsch_d_1" : "komp_deutsch_d",
    "komp_herkunft_1"  : "komp_herkunft",
    "komp_sozial_a_1"  : "komp_sozial_a",
    "komp_sozial_b_1"  : "komp_sozial_b",
    "komp_sozial_c_1"  : "komp_sozial_c",
    "komp_sozial_d_1"  : "komp_sozial_d",
    "komp_sozial_e_1"  : "komp_sozial_e",
    "komp_sozial_f_1"  : "komp_sozial_f",
    "komp_sozial_g_1"  : "komp_sozial_g",
    "komp_sozial_g_t_1": "komp_sozial_g_t",
    "komp_selbst_a_1"  : "komp_selbst_a",
    "komp_selbst_b_1"  : "komp_selbst_b",
    "komp_selbst_c_1"  : "komp_selbst_c",
    "komp_selbst_d_1"  : "komp_selbst_d",
    "komp_selbst_e_1"  : "komp_selbst_e",
    "komp_selbst_f_1"  : "komp_selbst_f",
    "komp_selbst_g_1"  : "komp_selbst_g",
    "komp_selbst_g_t_1": "komp_selbst_g_t",
    "komp_psy_a_1"     : "komp_psy_a",
    "komp_psy_b_1"     : "komp_psy_b",
    "komp_psy_c_1"     : "komp_psy_c",
    "komp_psy_d_1"     : "komp_psy_d",
    "komp_psy_e_1"     : "komp_psy_e",
    "komp_psy_f_1"     : "komp_psy_f",
    "komp_psy_g_1"     : "komp_psy_g",
    "komp_psy_g_t_1"   : "komp_psy_g_t",
    "komp_anm"         : "komp_anm",
    "entw_a_1"         : "entw_a",
    "entw_b_1"         : "entw_b",
    "entw_c_1"         : "entw_c",
    "entw_d_1"         : "entw_d",
    "entw_e_1"         : "entw_e",
    "entw_f_1"         : "entw_f",
    "entw_g_1"         : "entw_g",
    "entw_h_1"         : "entw_h",
    "entw_h_t_1"       : "entw_h_t",
    "entw_i_1"         : "entw_i",
    "entw_i_t_1"       : "entw_i_t",
    "entw_j_1"         : "entw_j",
    "entw_j_t_1"       : "entw_j_t",
    "entw_k_1"         : "entw_k",
    "entw_k_t_1"       : "entw_k_t",
    "entw_beh"         : "entw_beh",
    "dok_entw"         : "dok_entw"
}

def get_fkzs(cur):
    cur.execute(SELECT_FKZ)
    out = []
    while True:
        row = cur.fetchone()
        if not row: break
        out.append(row)
    return out

def handle(out_cur, fkz):

    id_counter = get_max_id('master_tbl', out_cur)

    database = fkz[1]

    con, cur = None, None
    print >> sys.stderr, "Processing '%s'" % database
    try:
        try:
            con = dbapi.connect(database = database)
        except:
            print >> sys.stderr, "Problem with db '%s'" % database
            return

        cur = con.cursor()

        cur.execute(ANON_TRANSFER)
        row = cur.fetchone()
        if not row or not row[0]:
            print >> sys.stderr, "No transfer allowed by '%s'" % database
            return

        cur.execute(SELECT)
        cases = []
        while True:
            row = cur.fetchone()
            if not row: break

            id_counter += 1
            fields, placeholders, values = ['id'], [':id'], {'id': id_counter}

            real_id = None

            for idx, x in enumerate(row):
                name = cur.description[idx][0]
                if name == 'id': real_id = x
                if name in BLACK_LIST or name in KOMPETENZ_FESTSTELLUNG:
                    continue                    
                if name == 'fkz': x = fkz[0]
                fields.append(name)
                placeholders.append(":%s" % name)
                values[name] = x

            stmnt = INSERT_STMT % {
                'fields':       ",".join(fields),
                'placeholders': ",".join(placeholders) }

            if real_id is not None:
                cases.append((real_id, id_counter))

            out_cur.execute(stmnt, values)

        status_counter = get_max_id('ka_status_tbl', out_cur)

        # copy ka_status_tbl
        for rid, nid in cases:
            cur.execute(SELECT_STATUS, { 'id': rid})
            row = cur.fetchone()
            if not row: continue
            status_counter += 1
            status, zugriff = row
            out_cur.execute(INSERT_STATUS, {
                'id'        : status_counter,
                'master_id' : nid,
                'status'    : status,
                'zugriff'   : zugriff
            })

        # copy rg_kompetenz_tbl

        kompetenz_counter = get_max_id('rg_kompetenz_tbl', out_cur)

        fields, values = ['id', 'master_id'], [':id', ':master_id']
        for k, v in KOMPETENZ_FESTSTELLUNG.iteritems():
            fields.append(v)
            values.append(":%s" % k)

        insert_stmnt = INSERT_KOMPETENZ % { 
            'fields': ','.join(fields), 
            'values': ','.join(values) }

        select_stmt = SELECT_KOMPETENZ % ",".join(KOMPETENZ_FESTSTELLUNG.iterkeys())

        for rid, nid in cases:
            cur.execute(select_stmt, { 'id': rid })
            while True:
                row = cur.fetchone()
                if not row: break
                kompetenz_counter += 1
                values = { 'id': kompetenz_counter, 'master_id': nid }
                for x, d in izip(row, cur.description):
                    values[d[0]] = x
                out_cur.execute(insert_stmnt, values)
    finally:
        if cur:
            try: cur.close()
            except: pass
        if con:
            try: con.close()
            except: pass

def main():
    outdb = None

    try:
        opts, args = getopt.getopt(sys.argv[1:], "o:", [ "out=" ])
    except getopt.GetoptError, err:
        usage(str(err), 1)

    for o, a in opts:
        if o in ("o", "-o", "--out"):
            outdb = a

    if outdb is None: usage("Error: missing out db",   1)

    out_con, out_cur = None, None

    try:
        out_con = db.connect(outdb)
        out_cur = out_con.cursor()

        fkzs = get_fkzs(out_cur)

        for fkz in fkzs:
            handle(out_cur, fkz)

        out_con.commit()
    finally:
        if out_cur:
            try: out_cur.close()
            except: pass
        if out_con:
            try: out_con.close()
            except: pass

if __name__ == '__main__':
    main()
