-- Hier finden sich zusätzliche Tabellen, die nicht durch den Formed generiert
-- werden.

CREATE TABLE ka_konfiguration_tbl
(
	id serial NOT NULL,
	bez varchar(64) NOT NULL,
	wert text,
	CONSTRAINT ka_konfiguration_tbl_pkey PRIMARY KEY (id)
);

INSERT INTO ka_konfiguration_tbl (bez, wert) VALUES ('fkz', '');
INSERT INTO ka_konfiguration_tbl (bez, wert) VALUES ('ka_name', '');
INSERT INTO ka_konfiguration_tbl (bez, wert) VALUES ('ee_formular', '');
INSERT INTO ka_konfiguration_tbl (bez, wert) VALUES ('fp_formular', '');
INSERT INTO ka_konfiguration_tbl (bez, wert) VALUES ('ud_formular', '');
INSERT INTO ka_konfiguration_tbl (bez, wert) VALUES ('anon_transfer', 'on');
INSERT INTO ka_konfiguration_tbl (bez, wert) VALUES ('max_speicherdauer', '90');
INSERT INTO ka_konfiguration_tbl (bez, wert) VALUES ('evaluation_id','');


CREATE TABLE ka_dokumente_tbl
(
	id serial NOT NULL,
    	uuid_id CHAR(36) UNIQUE,
	master_id int4 REFERENCES master_tbl(id) ON DELETE CASCADE,
	groesse int4,
	mime varchar(64),
	daten bytea, 
	name varchar(128),
	CONSTRAINT ka_dokumente_tbl_pkey PRIMARY KEY (id)
);

-- ka_status_tbl
--
-- Speichert Zustand und letzte Zugriffszeit der Fallakte.
-- Mögliche Zustände:
--	Offen (1) 
--	Geschlossen (2)
--	Schwebend-Gelöscht (3)
--	Schwebend-Anonymisiert (4)
--	Anonymsiert (5)

CREATE TABLE ka_status_tbl
(
	id serial NOT NULL,
	master_id int4 REFERENCES master_tbl(id) ON DELETE CASCADE,
	status    int4,
	zugriff   timestamp,
	erstellt  timestamp DEFAULT now(),
	anonymisiert timestamp,
	CONSTRAINT ka_status_tbl_pkey PRIMARY KEY (id)
);

-- ka_termine_tbl
-- 
-- Speichert grundlegende Angaben zu einem Termin. Weitergehende Angaben
-- sollten in einer extra Tabelle gespeichert werden.

CREATE TABLE ka_termine_tbl
(
	id serial NOT NULL,
	master_id int4 REFERENCES master_tbl(id) ON DELETE CASCADE,
	sdatum timestamp,
	edatum timestamp,
	name varchar(128),
	beschreibung text,
	art int4 DEFAULT 0, 
	CONSTRAINT ka_termine_tbl_pkey PRIMARY KEY (id)
);

-- ka_logbuch_art_tbl
--
-- Speichert die verschiedenen Arten von Logbuch-Eintraegen
--

CREATE TABLE ka_logbuch_art_tbl (
    id         SERIAL NOT NULL,
    beschreibung VARCHAR(256),
    CONSTRAINT ka_logbuch_art_tbl_pkey PRIMARY KEY (id)
);

GRANT SELECT ON ka_logbuch_art_tbl TO GROUP :cm_group;
GRANT SELECT ON ka_logbuch_art_tbl TO GROUP :admin_group;

-- Alte Aeintraege aus WASKA
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES (-2, 'Sonstiges');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES (-1, 'Keine Angabe');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 0, 'Automatischer Eintrag');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 1, 'Gespräch mit dem Jugendlichen');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 2, 'Telefonat mit dem Jugendlichen');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 3, 'Begleitung des Jugendlichen zu externen Stellen');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 4, 'Betreuung des Jugendlichen');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 5, 'Schriftverkehr');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 6, 'Gespräch/Telefonat mit Kooperationspartnern');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 7, 'Gespräch/Telefonat mit Dritten');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 8, 'Fallkonferenz (Fallbesprechung, Supervision)');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 9, 'Erstgespräch');
-- INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES (10, 'Kompetenzfeststellung');

-- unmittelbare Arbeit mit dem Jugendlichen
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 0, 'Automatischer Eintrag');
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 1, 'Gespräch mit dem/der Jugendlichen Kompetenzfeststellung'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 2, 'Kompetenzfeststellung'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 3, 'Korrespondenz mit dem/der Jugendlichen (Telefonate/Schriftverkehr)'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 4, 'Begleitung des/der Jugendlichen zu externen Stellen'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 5, 'Sonstige Betreuung des Jugendlichen'); 
-- Arbeit mit Eltern/Personensorgeberechtigte
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 6, 'Gespräch mit Eltern/Personensorgeberechtigten'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 7, 'Korrespondenz mit Eltern/Personensorgeberechtigten (Telefonat/Schriftverkehr)'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 8, 'Sonstige Maßnahmen der Elternarbeit'); 
-- Arbeit mit Dritten 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 9, 'Gespräch mit schulischen Mitarbeiter/-innen'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 10, 'Korrespondenz mit Schule (Telefonat/Schriftverkehr)'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 11, 'Korrespondenz mit Jugendhilfe (Telefonat/Schriftverkehr)'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 12, 'Gespräch mit beteiligten Dritten/Kooperationspartnern'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 13, 'Korrespondenz mit beteiligten Dritten/Kooperationspartnern (Telefonat/Schriftverkehr)'); 
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 14, 'Förder- bzw. Fallkonferenz');
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 19, 'Gespräch mit Mitarbeiter/-innen der Jugendhilfe');
-- Sonstiges
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 15, 'Fahrtwege');
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 16, 'Dokumentation WASKO');
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 17, 'Teambesprechung');
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES ( 18, 'Gespräch mit Mitarbeiter/-innen der Jugendhilfe');
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES (-2, 'Sonstiges');
INSERT INTO ka_logbuch_art_tbl (id, beschreibung) VALUES (-1, 'Keine Angabe');

-- ka_logbuch_tbl
--
-- Verwaltet Logbucheintraege zu Fallakten
--

-- Typ-Tabelle fuer Logbucheintrage. Im Moment nicht benutzt.
CREATE TABLE ka_logbuch_typ_tbl (
    id         SERIAL NOT NULL,
        beschreibung VARCHAR(256),
	    CONSTRAINT ka_logbuch_typ_tbl_pkey PRIMARY KEY (id)
	    );

GRANT SELECT ON ka_logbuch_typ_tbl TO GROUP :cm_group;
GRANT SELECT ON ka_logbuch_typ_tbl TO GROUP :admin_group;

-- INSERT INTO ka_logbuch_typ_tbl (id, beschreibung) VALUES (0, 'nicht aufsuchend');
-- INSERT INTO ka_logbuch_typ_tbl (id, beschreibung) VALUES (1, 'aufsuchend');
INSERT INTO ka_logbuch_typ_tbl (id, beschreibung) VALUES (-1, 'Keine Angabe');


CREATE TABLE ka_logbuch_tbl (
    id         SERIAL NOT NULL,
    master_id  int4 REFERENCES master_tbl(id)         ON DELETE CASCADE,
    uuid_id    CHAR(36),
    datum      TIMESTAMP,
    bearbeiter VARCHAR(256),
    art        int4 REFERENCES ka_logbuch_art_tbl(id) ON DELETE SET DEFAULT,
    typ        int4 REFERENCES ka_logbuch_typ_tbl(id) ON DELETE SET DEFAULT,
    kurz_notiz VARCHAR(256),
    notiz      text,
    dauer      interval,
    UNIQUE (uuid_id),
    CONSTRAINT ka_logbuch_tbl_pkey PRIMARY KEY (id)
);

-- ka_nachrichten_tbl
--
-- Verwaltet Logbucheintraege zu Fallakten
--

CREATE TABLE ka_nachrichten_art_tbl (
    id         SERIAL NOT NULL,
    beschreibung VARCHAR(128),
    CONSTRAINT ka_nachrichten_art_tbl_pkey PRIMARY KEY (id)
);

INSERT INTO ka_nachrichten_art_tbl (id, beschreibung) VALUES ( -2, 'Sonstiges');
INSERT INTO ka_nachrichten_art_tbl (id, beschreibung) VALUES ( -1, 'Keine Angabe');
INSERT INTO ka_nachrichten_art_tbl (id, beschreibung) VALUES (  0, 'Systemnachricht');

CREATE TABLE ka_nachrichten_tbl (
    id         SERIAL NOT NULL,
    datum      TIMESTAMP,
    art        int4 REFERENCES ka_nachrichten_art_tbl(id) ON DELETE SET DEFAULT,
    titel      VARCHAR(128),
    nachricht  text,
    CONSTRAINT ka_nachrichten_tbl_pkey PRIMARY KEY (id)
);

CREATE TABLE nm_benutzer_nachrichten_tbl 
(
	id serial NOT NULL,
	benutzer_id int4 REFERENCES ka_benutzer_tbl(id) ON DELETE CASCADE,
	nachrichten_id int4 REFERENCES ka_nachrichten_tbl(id) ON DELETE CASCADE,
	gelesen timestamp DEFAULT now(),
	CONSTRAINT nm_benutzer_news_pkey PRIMARY KEY (id)
);

-- ka_tags_tbl
-- Enthaelt tags, die an Fallakten gehangen werden koennen

CREATE TABLE tags (
    id          SERIAL PRIMARY KEY,
    label       VARCHAR(256) NOT NULL,
    description TEXT,
    systemtag   BOOLEAN DEFAULT TRUE
);

CREATE TABLE nm_tags_cases ( 
    id SERIAL PRIMARY KEY,
    master_id   integer NOT NULL REFERENCES master_tbl(id) ON DELETE CASCADE,
    tag_id    integer NOT NULL REFERENCES tags(id)       ON DELETE CASCADE,
    created   TIMESTAMP DEFAULT now(),
    UNIQUE (master_id, tag_id)
);

-- Add systemtags

-- Autogenerated tag insert statements
INSERT INTO tags (id, label, description) VALUES (0, 'Alle', 'Jede Fallakte hat einen Tag');
INSERT INTO tags (id, label, description) VALUES (1, 'Grundsätzlich auswertbar', 'Die Fallakte ist konsistent und weist die benötigten Validitäten auf, die für eine grundsätzliche Auswertung erfüllt sein müssen. Die Fallakte steht in Auswertungen zur Verfügung');
INSERT INTO tags (id, label, description) VALUES (2, 'Berichtsfähig', 'Eine Fallakte ist grundsätzlich auswertbar. Sie befindet sich darüber hinaus mindestens im laufendem CM und enthält eine Geschlechtsangabe. Die Fallakte steht für Auswertungen wie den Verwendungsnachweis zur Verfügung');
INSERT INTO tags (id, label, description) VALUES (10, 'Datumsangaben konsistent', 'Alle Datumsangaben in der Fallakte befinden sich in chronologisch korrekter Reihenfolge und liegen nicht in der Zukunft');
INSERT INTO tags (id, label, description) VALUES (11, 'Phase ist gesetzt', 'Die Phase der Fallakte ist nicht unbekannt');
INSERT INTO tags (id, label, description) VALUES (12, 'Synchronität der Phasen ist gegeben', 'Die in der Fallakte angegebenen Datumsangaben sind nicht weiter ausgefüllt, als es die aktuell gesetzte Phase. Z.b ein gesetzten Beendigungsdatum bei laufender Phase');
INSERT INTO tags (id, label, description) VALUES (13, 'Junger Mensch ist ein CM-Kunde', 'Für den jungen Menschen wurde im Phasenmodell mindestens ein laufendes Case Management dokumentiert');
INSERT INTO tags (id, label, description) VALUES (14, 'Geschlechtsangabe angegeben', 'Die Geschlechtsangabe des jungen Menschen ist angegeben und hat nicht den Wert "unbekannt"');
INSERT INTO tags (id, label, description) VALUES (17, 'Die Dauer der Phasen überschreitet nicht die maximale Länge', 'Die Regeln, die sicherstellen das die Phasen nicht die maximale Länge überschreiten, sind erfüllt.');
INSERT INTO tags (id, label, description) VALUES (101, 'Mindestdatum nicht gegeben', 'Das Datum muss nach dem 1.1.1970 liegen');
INSERT INTO tags (id, label, description) VALUES (110, 'Ende Wiederaufnahme max 93Tage > als Genehmigung Wiederaufnahme', 'Zeitraum der genehmigten Wiederaufnahme zu groß');
INSERT INTO tags (id, label, description) VALUES (111, 'Ende Wiederaufnahme max 93Tage > als Beendigung Wiederaufnahme 1', 'Zeitraum der genehmigten Wiederaufnahme zu groß');
INSERT INTO tags (id, label, description) VALUES (112, 'Dauer der Verlängerung > 93Tage nach Ende letzter Verlängerung', 'Ende der Verlängerung darf max 3 Monate nach dem Ende der ersten Verlängerung liegen');
INSERT INTO tags (id, label, description) VALUES (113, 'Dauer der Verlängerung > 458 Tage nach Beginn CM', 'Ende der Verlängerung darf max 12 Monate + 3 Monate nach dem Beginn der Aufnahme in das CM liegen.');
INSERT INTO tags (id, label, description) VALUES (200, 'Phase NB darf nicht gestartet werden wenn Art der Beendigung keine erfolgreiche Reeintegration ist', 'Eine Nachbetreuung darf nur bei einer erfolgreichen Reintegration begonnen werden.');
INSERT INTO tags (id, label, description) VALUES (201, 'Phase NB darf nur gestartet werden wenn eine Nachbetreuung geplant ist', 'Eine Nachbetreuung darf nur bei einer geplanten Nachbetreuung begonnen werden.');
INSERT INTO tags (id, label, description) VALUES (900, 'Phase EA nicht länger als 12 monate', 'Die eingetragenen Datumsangaben sind offensichtlich falsch und überschreiten die maximale Dauer der Phase "Eingangsanamnese". Bitte korrigieren Sie Ihre Angaben, da die Fallakte andernfalls nicht auswertbar ist.');
INSERT INTO tags (id, label, description) VALUES (901, 'Phase CM  nicht länger als 18 monate', 'Die eingetragenen Datumsangaben (inklusive der Verlängerungen des CM) sind offensichtlich falsch und überschreiten die maximale Dauer der Phase "Case Management". Bitte korrigieren Sie Ihre Angaben, da die Fallakte andernfalls nicht auswertbar ist.');
INSERT INTO tags (id, label, description) VALUES (902, 'Phase NB nicht länger als 12 monate', 'Die eingetragenen Datumsangaben sind offensichtlich falsch und überschreiten die maximale Dauer der Phase "Nachbetreuung". Bitte korrigieren Sie Ihre Angaben, da die Fallakte andernfalls nicht auswertbar ist.');
INSERT INTO tags (id, label, description) VALUES (1000, '"geburtsdatum" muss vor "kontakt" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum des Erstkontakt zum/zur Jugendlichen" liegen.');
INSERT INTO tags (id, label, description) VALUES (1001, '"geburtsdatum" muss vor "nat_wohn" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum wohnhaft in Deutschland seit" liegen.');
INSERT INTO tags (id, label, description) VALUES (1002, '"vater_gb" muss vor "geburtsdatum" liegen.', '"" darf zeitlich nicht nach "" liegen.');
INSERT INTO tags (id, label, description) VALUES (1003, '"geburtsdatum" muss vor "datum_kf_1" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beginn der Kompetenzfeststellung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1004, '"geburtsdatum" muss vor "nbetr_ende" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Ende der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1005, '"geburtsdatum" muss vor "erstgespraech" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum des Erstgesprächs mit dem/der Jugendlichen" liegen.');
INSERT INTO tags (id, label, description) VALUES (1006, '"geburtsdatum" muss vor "datum_bfplan" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beginn der Bildungs- und Förderplanung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1007, '"geburtsdatum" muss vor "datum_cm_start" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beginn der Umsetzung des Case Management in der Koordinierungsstelle" liegen.');
INSERT INTO tags (id, label, description) VALUES (1008, '"geburtsdatum" muss vor "nbetr_start" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Start der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1009, '"geburtsdatum" muss vor "datum_cm_ende" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beendigung des Case Management" liegen.');
INSERT INTO tags (id, label, description) VALUES (1010, '"mutter_gb" muss vor "geburtsdatum" liegen.', '"" darf zeitlich nicht nach "" liegen.');
INSERT INTO tags (id, label, description) VALUES (1011, '"geburtsdatum" darf nicht in der Zukunft liegen.', '"Geburtsdatum" darf nicht in der Zukunft liegen.');
INSERT INTO tags (id, label, description) VALUES (1013, '"cm_dok_datum_beendigung" muss vor "cm_wiederauf_datum_bis_2" liegen.', '"Datum der Beendigung" darf zeitlich nicht nach "Datum Wiederaufnahme genehmigt bis" liegen.');
INSERT INTO tags (id, label, description) VALUES (1014, '"cm_dok_datum_beendigung" muss vor "cm_wiederauf_genehm_datum_1" liegen.', '"Datum der Beendigung" darf zeitlich nicht nach "Datum Wiederaufnahme" liegen.');
INSERT INTO tags (id, label, description) VALUES (1015, '"cm_dok_datum_beendigung" muss vor "cm_wiederauf_datum_bis_1" liegen.', '"Datum der Beendigung" darf zeitlich nicht nach "Datum Wiederaufnahme genehmigt bis" liegen.');
INSERT INTO tags (id, label, description) VALUES (1017, '"cm_wiederauf_genehm_datum_1" muss vor "cm_wiederauf_datum_bis_2" liegen.', '"Datum Wiederaufnahme" darf zeitlich nicht nach "Datum Wiederaufnahme genehmigt bis" liegen.');
INSERT INTO tags (id, label, description) VALUES (1018, '"cm_wiederauf_datum_bis_1" muss vor "cm_wiederauf_datum_bis_2" liegen.', '"" darf zeitlich nicht nach "" liegen.');
INSERT INTO tags (id, label, description) VALUES (1019, '"cm_wiederauf_genehm_datum_1" muss vor "cm_wiederauf_datum_bis_1" liegen.', '"Datum Wiederaufnahme" darf zeitlich nicht nach "Datum Wiederaufnahme genehmigt bis" liegen.');
INSERT INTO tags (id, label, description) VALUES (1021, 'Das Datum darf nicht "unbekannt" sein.', 'Das Datum darf nicht "unbekannt" sein.');
INSERT INTO tags (id, label, description) VALUES (1022, '"kontakt" muss vor "nbetr_start" liegen.', '"Datum des Erstkontakt zum/zur Jugendlichen" darf zeitlich nicht nach "Datum Start der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1023, '"erstgespraech" muss vor "nbetr_ende" liegen.', '"Datum des Erstgesprächs mit dem/der Jugendlichen" darf zeitlich nicht nach "Datum Ende der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1024, '"erstgespraech" muss vor "datum_cm_ende" liegen.', '"Datum des Erstgesprächs mit dem/der Jugendlichen" darf zeitlich nicht nach "Datum Beendigung des Case Management" liegen.');
INSERT INTO tags (id, label, description) VALUES (1025, '"mutter_gb" muss vor "kontakt" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum des Erstkontakt zum/zur Jugendlichen" liegen.');
INSERT INTO tags (id, label, description) VALUES (1026, '"kontakt" muss vor "datum_cm_start" liegen.', '"Datum des Erstkontakt zum/zur Jugendlichen" darf zeitlich nicht nach "Datum Beginn der Umsetzung des Case Management in der Koordinierungsstelle" liegen.');
INSERT INTO tags (id, label, description) VALUES (1027, '"kontakt" muss vor "datum_bfplan" liegen.', '"Datum des Erstkontakt zum/zur Jugendlichen" darf zeitlich nicht nach "Datum Beginn der Bildungs- und Förderplanung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1028, '"kontakt" muss vor "datum_cm_ende" liegen.', '"Datum des Erstkontakt zum/zur Jugendlichen" darf zeitlich nicht nach "Datum Beendigung des Case Management" liegen.');
INSERT INTO tags (id, label, description) VALUES (1029, '"vater_gb" muss vor "kontakt" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum des Erstkontakt zum/zur Jugendlichen" liegen.');
INSERT INTO tags (id, label, description) VALUES (1030, '"erstgespraech" muss vor "nbetr_start" liegen.', '"Datum des Erstgesprächs mit dem/der Jugendlichen" darf zeitlich nicht nach "Datum Start der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1031, '"kontakt" muss vor "nbetr_ende" liegen.', '"Datum des Erstkontakt zum/zur Jugendlichen" darf zeitlich nicht nach "Datum Ende der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1032, '"vater_gb" muss vor "erstgespraech" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum des Erstgesprächs mit dem/der Jugendlichen" liegen.');
INSERT INTO tags (id, label, description) VALUES (1033, '"mutter_gb" muss vor "erstgespraech" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum des Erstgesprächs mit dem/der Jugendlichen" liegen.');
INSERT INTO tags (id, label, description) VALUES (1034, '"erstgespraech" muss vor "datum_cm_start" liegen.', '"Datum des Erstgesprächs mit dem/der Jugendlichen" darf zeitlich nicht nach "Datum Beginn der Umsetzung des Case Management in der Koordinierungsstelle" liegen.');
INSERT INTO tags (id, label, description) VALUES (1035, '"erstgespraech" muss vor "datum_bfplan" liegen.', '"Datum des Erstgesprächs mit dem/der Jugendlichen" darf zeitlich nicht nach "Datum Beginn der Bildungs- und Förderplanung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1036, '"kontakt" muss vor "erstgespraech" liegen.', '"Datum des Erstkontakt zum/zur Jugendlichen" darf zeitlich nicht nach "Datum des Erstgesprächs mit dem/der Jugendlichen" liegen.');
INSERT INTO tags (id, label, description) VALUES (1037, '"datum_cm_start" muss vor "nbetr_ende" liegen.', '"Datum Beginn der Umsetzung des Case Management in der Koordinierungsstelle" darf zeitlich nicht nach "Datum Ende der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1038, '"datum_cm_start" muss vor "datum_bfplan" liegen.', '"Datum Beginn der Umsetzung des Case Management in der Koordinierungsstelle" darf zeitlich nicht nach "Datum Beginn der Bildungs- und Förderplanung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1039, '"vater_gb" muss vor "datum_cm_start" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beginn der Umsetzung des Case Management in der Koordinierungsstelle" liegen.');
INSERT INTO tags (id, label, description) VALUES (1040, '"mutter_gb" muss vor "datum_cm_start" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beginn der Umsetzung des Case Management in der Koordinierungsstelle" liegen.');
INSERT INTO tags (id, label, description) VALUES (1041, '"datum_cm_start" muss vor "nbetr_start" liegen.', '"Datum Beginn der Umsetzung des Case Management in der Koordinierungsstelle" darf zeitlich nicht nach "Datum Start der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1042, '"datum_cm_start" muss vor "datum_cm_ende" liegen.', '"Datum Beginn der Umsetzung des Case Management in der Koordinierungsstelle" darf zeitlich nicht nach "Datum Beendigung des Case Management" liegen.');
INSERT INTO tags (id, label, description) VALUES (1043, '"mutter_gb" muss vor "nat_wohn" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum wohnhaft in Deutschland seit" liegen.');
INSERT INTO tags (id, label, description) VALUES (1044, '"vater_gb" muss vor "nat_wohn" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum wohnhaft in Deutschland seit" liegen.');
INSERT INTO tags (id, label, description) VALUES (1045, '"mutter_gb" muss vor "nbetr_start" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Start der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1046, '"mutter_gb" muss vor "nbetr_ende" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Ende der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1047, '"mutter_gb" muss vor "datum_bfplan" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beginn der Bildungs- und Förderplanung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1048, '"mutter_gb" muss vor "datum_cm_ende" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beendigung des Case Management" liegen.');
INSERT INTO tags (id, label, description) VALUES (1049, '"mutter_gb" muss vor "datum_kf_1" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beginn der Kompetenzfeststellung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1050, '"mutter_gb" darf nicht in der Zukunft liegen.', '"Geburtsdatum" darf nicht in der Zukunft liegen.');
INSERT INTO tags (id, label, description) VALUES (1051, '"vater_gb" muss vor "datum_bfplan" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beginn der Bildungs- und Förderplanung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1052, '"vater_gb" muss vor "nbetr_start" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Start der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1053, '"vater_gb" muss vor "datum_cm_ende" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beendigung des Case Management" liegen.');
INSERT INTO tags (id, label, description) VALUES (1054, '"vater_gb" muss vor "datum_kf_1" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Beginn der Kompetenzfeststellung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1055, '"vater_gb" muss vor "nbetr_ende" liegen.', '"Geburtsdatum" darf zeitlich nicht nach "Datum Ende der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1056, '"vater_gb" darf nicht in der Zukunft liegen.', '"Geburtsdatum" darf nicht in der Zukunft liegen.');
INSERT INTO tags (id, label, description) VALUES (1057, '"datum_bfplan" muss vor "nbetr_ende" liegen.', '"Datum Beginn der Bildungs- und Förderplanung" darf zeitlich nicht nach "Datum Ende der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1058, '"datum_bfplan" muss vor "datum_cm_ende" liegen.', '"Datum Beginn der Bildungs- und Förderplanung" darf zeitlich nicht nach "Datum Beendigung des Case Management" liegen.');
INSERT INTO tags (id, label, description) VALUES (1059, '"datum_bfplan" muss vor "nbetr_start" liegen.', '"Datum Beginn der Bildungs- und Förderplanung" darf zeitlich nicht nach "Datum Start der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1061, '"cm_datum_verlaengerung_1" muss vor "cm_datum_verlaengerung_2" liegen.', '"Datum erste Verlängerung" darf zeitlich nicht nach "Datum zweite Verlängerung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1063, 'Das Datum darf nicht "unbekannt" sein.', 'Das Datum darf nicht "unbekannt" sein.');
INSERT INTO tags (id, label, description) VALUES (1064, '"datum_cm_ende" muss vor "nbetr_ende" liegen.', '"Datum Beendigung des Case Management" darf zeitlich nicht nach "Datum Ende der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1065, '"datum_cm_ende" muss vor "nbetr_start" liegen.', '"Datum Beendigung des Case Management" darf zeitlich nicht nach "Datum Start der Nachbetreuung" liegen.');
INSERT INTO tags (id, label, description) VALUES (1068, 'Das Datum darf nicht "unbekannt" sein.', 'Das Datum darf nicht "unbekannt" sein.');
INSERT INTO tags (id, label, description) VALUES (1069, 'Das Datum darf nicht "unbekannt" sein.', 'Das Datum darf nicht "unbekannt" sein.');
INSERT INTO tags (id, label, description) VALUES (1070, '"nbetr_start" muss vor "nbetr_ende" liegen.', '"Datum Start der Nachbetreuung" darf zeitlich nicht nach "Datum Ende der Nachbetreuung" liegen.');
-- Move tags serial: userdefined tags start at 1000
ALTER SEQUENCE tags_id_seq RESTART 1000;

CREATE TABLE dbinfo (
    id INTEGER PRIMARY KEY NOT NULL,
    key   VARCHAR(128) NOT NULL,
    value VARCHAR(256) 
);

INSERT INTO dbinfo (id, key, value) VALUES (1, 'version', CURRENT_DATE);
INSERT INTO dbinfo (id, key, value) VALUES (2, 'datadump', NULL);

GRANT SELECT ON dbinfo TO PUBLIC;
