#!/usr/bin/env python
#
# (c) 2009 Intevation GmbH
#
# author: Sascha L. Teichmann
#

import sys
import re

class FieldType(object):

    def __init__(self, regex, action_name):
        self.action_name = action_name
        self.regex = re.compile(regex)
        self.items = []

    def eat(self, field_name):
        m = self.regex.match(field_name)
        if not m: return False
        x = []
        for i in m.groups():
            try:
                x.append(int(i))
            except ValueError:
                x.append(i)
        
        self.items.append((tuple(x), field_name))
        return True

    def printout(self):
        if not self.items: return

        print "def %s(value, parameters, context):" % self.action_name
        print "    # parameters:", ", ".join([str(x) for x in sorted([y[0] for y in self.items])])
        print "    pass"
        print

    def generate_lookup(self, out):
        for item in self.items:
            out.append("'%s': lambda v, ctx: %s(v, %s, ctx)" % (
                item[1], self.action_name, repr(item[0])))

class DefaultFieldType(FieldType):

    def __init__(self):
        FieldType.__init__(self, ".*", "")

    def printout(self):
        for item in self.items:
            print "def %s(value, parameters, context):" % item[1]
            print "    # parameters: ()"
            print "    pass"
            print

    def generate_lookup(self, out):
        for item in self.items:
            out.append("'%s': lambda v, ctx: %s(v, %s, ctx)" % (
                item[1], item[1], repr(item[0])))

def main():
    orig = len(sys.argv) > 1 and sys.argv[1] or "orig"
    rgs  = len(sys.argv) > 2 and sys.argv[2] or "rgs"

    orig_set = set()
    f = open(orig)
    for line in f: orig_set.add(line.strip())
    f.close()

    rgs_set = set()
    f = open(rgs)
    for line in f: rgs_set.add(line.strip())
    f.close()

    # Felder, die in der neuen master_tbl nicht vorkommen
    # und daher gemappt werden muessen
    orig_without_rgs = orig_set - rgs_set

    rest = DefaultFieldType()

    field_types = [
        FieldType("kd_institution_email_(\d+)", "kd_institution_email_A"),
        FieldType("kd_institution_name_(\d+)", "kd_institution_name_A"),
        FieldType("kd_institution_ort_(\d+)", "kd_institution_ort_A"),
        FieldType("kd_institution_plz_(\d+)", "kd_institution_plz_A"),
        FieldType("kd_institution_strasse_(\d+)", "kd_institution_strasse_A"),
        FieldType("kd_institution_vorwahl_(\d+)", "kd_institution_vorwahl_A"),
        FieldType("kd_institution_kundennummer_(\d+)", "kd_institution_kundennummer_A"),
        FieldType("kd_institution_strassenr_(\d+)", "kd_institution_strassenr_A"),
        FieldType("kd_institution_telefonnummer_(\d+)", "kd_institution_telefonnummer_A"),

        FieldType("kd_bezug_email_(\d+)", "kd_bezug_email_A"),
        FieldType("kd_bezug_strasse_(\d+)", "kd_bezug_strasse_A"),
        FieldType("kd_bezug_plz_(\d+)", "kd_bezug_plz_A"),
        FieldType("kd_bezug_strassenr_(\d+)", "kd_bezug_strassenr_A"),
        FieldType("kd_bezug_ort_(\d+)", "kd_bezug_ort_A"),
        FieldType("kd_bezug_vorname_(\d+)", "kd_bezug_vorname_A"),
        FieldType("kd_bezug_name_(\d+)", "kd_bezug_name_A"),
        FieldType("kd_bezug_funktion_(\d+)", "kd_bezug_funktion_A"),
        FieldType("kd_bezug_(\d+)_telefon", "kd_bezug_A_telefon"),
        FieldType("kd_bezug_(\d+)_vorwahl", "kd_bezug_A_vorwahl"),

        FieldType("kd_jugendamt_vorwahl_(\d)", "kd_jugendamt_vorwahl_A"),
        FieldType("kd_jugendamt_strasse_(\d)", "kd_jugendamt_strasse_A"),
        FieldType("kd_jugendamt_strassenr_(\d)", "kd_jugendamt_strassenr_A"),
        FieldType("kd_jugendamt_email_(\d)", "kd_jugendamt_email_A"),
        FieldType("kd_jugendamt_plz_(\d)", "kd_jugendamt_plz_A"),
        FieldType("kd_jugendamt_ort_(\d)", "kd_jugendamt_ort_A"),
        FieldType("kd_jugendamt_kundennummer_(\d)", "kd_jugendamt_kundennummer_A"),
        FieldType("kd_jugendamt_telefonnummer_(\d)", "kd_jugendamt_telefonnummer_A"),

        FieldType("kd_schule_vorwahl_(\d)", "kd_schule_vorwahl_A"),
        FieldType("kd_schule_strasse_(\d)", "kd_schule_strasse_A"),
        FieldType("kd_schule_strassenr_(\d)", "kd_schule_strassenr_A"),
        FieldType("kd_schule_email_(\d)", "kd_schule_email_A"),
        FieldType("kd_schule_plz_(\d)", "kd_schule_plz_A"),
        FieldType("kd_schule_ort_(\d)", "kd_schule_ort_A"),
        FieldType("kd_schule_name_(\d)", "kd_schule_name_A"),
        FieldType("kd_schule_telefonnummer_(\d)", "kd_schule_telefonnummer_A"),

        FieldType("fehlutg_(\d+)", "fehlutg_A"),
        FieldType("fehl([mj])_(\d+)", "fehlA_B"),
        FieldType("fehltg_(\d+)", "fehltg_A"),
        FieldType("fehlfust_(\d+)", "fehlfust_A"),
        FieldType("fehlst_(\d+)", "fehlst_A"),

        FieldType("entw_beh", "entw_beh"),
        FieldType("entw_([a-k])_(\d+)", "entw_A_B"),
        FieldType("entw_([hijk])_t_(\d+)", "entw_A_t_B"),

        FieldType("hilfm_(\d+)", "hilfm_A"),
        FieldType("hilfm_ende_(\d+)", "hilfm_ende_A"),
        FieldType("hilfm_start_(\d+)", "hilfm_start_A"),
        FieldType("hilfm_sf_(\d+)", "hilfm_sf_A"),
        FieldType("hilfm_umf_(\d+)", "hilfm_umf_A"),
        FieldType("hilfm_erreicht_(\d+)_(\d)", "hilfm_erreicht_A_B"),
        FieldType("hilfm_ziel_(\d+)_(\d+)", "hilfm_ziel_A_B"),
        FieldType("hilfm_inst_(\d+)", "hilfm_inst_A"),
        FieldType("hilfm_zeit_(\d+)_(\d+)", "hilfm_zeit_A_B"),
        FieldType("hilfm_art_(\d+)", "hilfm_art_A"),
        FieldType("hilfm_einr_(\d+)", "hilfm_einr_A"),

        FieldType("komp_schule_([a-g])_(\d+)", "komp_schule_A_B"),
        FieldType("komp_sozial_([a-g])_(\d+)", "komp_sozial_A_B"),
        FieldType("komp_deutsch_([a-d])_(\d+)", "komp_deutsch_A_B"),
        FieldType("komp_selbst_([a-g])_(\d+)", "komp_selbst_A_B"),
        FieldType("komp_psy_([a-g])_(\d+)", "komp_psy_A_B"),
        FieldType("komp_herkunft_(\d+)", "komp_herkunft_A"),
        FieldType("komp_(selbst|schule|sozial|psy)_g_t_1", "komp_X_g_t_1"),
        FieldType("komp_anm", "komp_anm"),

        FieldType("datum_kf_(\d+)", "datum_kf_A"),
        FieldType("kf_anbiet_(\d+)", "kf_anbiet_A"),
        FieldType("kf_verfahren_(\d+)", "kf_verfahren_A"),
        FieldType("kf_meth_([a-f])_1", "kf_meth_A_1"),
        FieldType("kf_test_([a-f])_1", "kf_test_A_1"),
        FieldType("kf_test_([a-f])_t_1", "kf_test_A_t_1"),
        FieldType("kf_meth_([a-f])_t_1", "kf_meth_A_t_1"),

        FieldType("mutter_telefonnummer(\d+)_(\d)", "mutter_telefonnummerA_B"),
        FieldType("mutter_vorwahl(\d+)_(\d)", "mutter_vorwahlA_B"),
        FieldType("mutter_email_(\d+)", "mutter_email_A"),
        FieldType("mutter_plz_(\d+)", "mutter_plz_A"),
        FieldType("mutter_ort_(\d+)", "mutter_ort_A"),
        FieldType("mutter_strasse_(\d+)", "mutter_strasse_A"),
        FieldType("mutter_strassenr_(\d+)", "mutter_strassenr_A"),

        FieldType("vater_telefonnummer(\d+)_(\d)", "vater_telefonnummerA_B"),
        FieldType("vater_vorwahl(\d+)_(\d)", "vater_vorwahlA_B"),
        FieldType("vater_email_(\d+)", "vater_email_A"),
        FieldType("vater_plz_(\d+)", "vater_plz_A"),
        FieldType("vater_ort_(\d+)", "vater_ort_A"),
        FieldType("vater_strasse_(\d+)", "vater_strasse_A"),
        FieldType("vater_strassenr_(\d+)", "vater_strassenr_A"),

        FieldType("addresse(\d+)_telefonnummer_(\d+)", "addresseA_telefonnummer_B"),
        FieldType("addresse(\d+)_vorwahl_(\d+)", "addresseA_vorwahl_B"),
        FieldType("addresse_plz_(\d+)", "addresse_plz_A"),
        FieldType("addresse_ort_(\d+)", "addresse_ort_A"),
        FieldType("addresse_email_(\d+)", "addresse_email_A"),
        FieldType("addresse_strasse_(\d+)", "addresse_strasse_A"),
        FieldType("addresse_strassenr_(\d+)", "addresse_strassenr_A"),
        FieldType("addresse_weiteretelefonnummern_(\d+)", "addresse_weiteretelefonnummern_A"),

        FieldType("bezugs_email_(\d+)", "bezugs_email_A"),
        FieldType("bezugs_vorname_(\d+)", "bezugs_vorname_A"),
        FieldType("bezugs_name_(\d+)", "bezugs_name_A"),
        FieldType("bezugs_telefonnummer_(\d+)", "bezugs_telefonnummer_A"),
        FieldType("bezugs_vorwahl_(\d+)", "bezugs_vorwahl_A"),

        FieldType("dok_entw", "dok_entw"),

        rest
    ]

    not_mapped = []

    for field_name in orig_without_rgs:
        found = False
        for ft in field_types:
            if ft.eat(field_name): found = True; break
        if not found:
            not_mapped.append(field_name)

    print "# FILL THE FOLLOWING FUNCTIONS WITH THE SPECIFIC CONVERSIONS:"
    print

    for ft in field_types:
        ft.printout()

    print

    print "# LEAVE THE LOOKUP MAP UNTOUCHED!"
    print

    out = []
    for ft in field_types: ft.generate_lookup(out)
    print "LOOKUP = {\n    %s" % ",\n    ".join(out)
    print "}"
    print

    # Felder, die nur in der neuen master_tbl vorkommen.
    only_in_new = rgs_set - orig_set

    print "# FIELDS ONLY IN NEW:", len(only_in_new)
    print
    print "ONLY_IN_NEW = set([\n    %s])" % \
        ",\n    ".join(['"%s"' % i for i in sorted(only_in_new)])
    print

    # Felder, die in beiden vorhanden sind, koennen 
    # durchkopiert werden.
    in_both = orig_set & rgs_set

    print "# FIELDS TO BE COPIED THROUGH:", len(in_both)
    print
    print "COPY_THRU = set([\n    %s])" % \
        ",\n    ".join(['"%s"' % i for i in sorted(in_both)])
    print

    print "# not mapped:", len(not_mapped)
    print "# default mapped:", len(rest.items)

if __name__ == '__main__':
    main()
