BEGIN;

-- ka_tags_tbl
-- Enthaelt tags, die an Fallakten gehangen werden koennen

-- Funktion zur Uebergabe einer falls zum tagging
-- (https://waska-intern.intevation.de/taggingDaemon)
CREATE OR REPLACE FUNCTION check_case(ds_id integer) RETURNS void 
AS $$
import socket

UNIX_SOCKET = "/tmp/tagd-socket"

db = plpy.execute("SELECT current_database() as db")[0]["db"]

s = None
try:
    try:
        s = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
        s.connect(UNIX_SOCKET)
        s.send("%s %d\n" % (db, ds_id))
    except:
        plpy.warning('Can not connect tagd socket')
finally:
    if s:
        try: s.close()
        except: pass
          
$$ LANGUAGE plpythonu;

SET ROLE :db_adm;

INSERT INTO db_history (beschreibung, zeitpunkt)
       VALUES ('1.1.0/01_tags.sql', current_timestamp);


CREATE TABLE tags (
    id          SERIAL PRIMARY KEY,
    label       VARCHAR(256) NOT NULL UNIQUE,
    description TEXT,
    systemtag   BOOLEAN DEFAULT TRUE
);

CREATE TABLE nm_tags_cases ( 
    id SERIAL PRIMARY KEY,
    master_id   integer NOT NULL REFERENCES master_tbl(id) ON DELETE CASCADE,
    tag_id    integer NOT NULL REFERENCES tags(id)       ON DELETE CASCADE,
    created   TIMESTAMP DEFAULT now(),
    UNIQUE (master_id, tag_id)
);

-- Add systemtags
INSERT INTO tags (id, label, description) VALUES (0, 'Alle','');
INSERT INTO tags (id, label, description) VALUES (1, 'konsistent','');
INSERT INTO tags (id, label, description) VALUES (2, 'phasenvollstaendig','');
INSERT INTO tags (id, label, description) VALUES (3, 'auswertbar','');
INSERT INTO tags (id, label, description) VALUES (4, 'adele-auswertbar','');

-- Move tags serial: userdefined tags start at 1000
ALTER SEQUENCE tags_id_seq RESTART 1000;

CREATE OR REPLACE VIEW tags_view 
    AS SELECT
        id,
        label,
        description,
        systemtag
    FROM tags;

CREATE OR REPLACE RULE tags_update_rule
    AS ON UPDATE TO tags_view 
	DO INSTEAD
        UPDATE tags SET
            label      = new.label,
            description = new.description,
            systemtag = new.systemtag
	    WHERE tags.id = new.id;

CREATE OR REPLACE RULE tags_delete_rule 
    AS ON DELETE TO  tags_view DO INSTEAD NOTHING;

CREATE OR REPLACE RULE tags_insert_rule
    AS ON INSERT TO tags_view DO INSTEAD NOTHING;


GRANT SELECT ON tags_view TO GROUP :cm_group;
GRANT UPDATE ON tags_view TO GROUP :cm_group;
GRANT SELECT ON tags_view TO GROUP :admin_group;
GRANT UPDATE ON tags_view TO GROUP :admin_group;

CREATE OR REPLACE VIEW nm_tags_cases_view 
    AS SELECT
        id,
        master_id as case_id,
        tag_id,
        created 
    FROM nm_tags_cases;

GRANT SELECT ON nm_tags_cases_view TO GROUP :cm_group;
GRANT UPDATE ON nm_tags_cases_view TO GROUP :cm_group;
GRANT SELECT ON nm_tags_cases_view TO GROUP :admin_group;
GRANT UPDATE ON nm_tags_cases_view TO GROUP :admin_group;

CREATE OR REPLACE FUNCTION create_nm_tag_case_ds ( tagid integer, 
    masterid integer ) RETURNS integer
    LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER
    AS $$
BEGIN
    INSERT INTO nm_tags_cases (tag_id, master_id) 
        VALUES (tagid, masterid);
    RETURN currval('nm_tags_cases_id_seq');
END;
$$ ;

REVOKE ALL ON FUNCTION create_nm_tag_case_ds(integer, integer) 
                FROM PUBLIC;
GRANT EXECUTE ON FUNCTION create_nm_tag_case_ds(integer, integer) 
                TO GROUP :cm_group;
GRANT EXECUTE ON FUNCTION create_nm_tag_case_ds(integer, integer) 
                TO GROUP :admin_group;


CREATE OR REPLACE FUNCTION delete_nm_tag_case_ds ( tagid integer,
    masterid integer ) RETURNS VOID 
    LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER
    AS $$
BEGIN
    DELETE FROM nm_tags_cases 
            WHERE master_id = masterid AND tag_id = tagid; 
END;
$$ ;

REVOKE ALL ON FUNCTION delete_nm_tag_case_ds(integer, integer) 
                FROM PUBLIC;
GRANT EXECUTE ON FUNCTION delete_nm_tag_case_ds(integer, integer) 
                TO GROUP :cm_group;
GRANT EXECUTE ON FUNCTION delete_nm_tag_case_ds(integer, integer) 
                TO GROUP :admin_group;

CREATE OR REPLACE FUNCTION delete_tag_ds ( tagid integer) RETURNS VOID 
    LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER
    AS $$
BEGIN
    DELETE FROM tags WHERE id = tagid; 
END;
$$ ;

REVOKE ALL ON FUNCTION delete_tag_ds(integer) 
                FROM PUBLIC;
GRANT EXECUTE ON FUNCTION delete_tag_ds(integer) 
                TO GROUP :admin_group;

CREATE OR REPLACE FUNCTION create_tag_ds () RETURNS INTEGER 
    LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER
    AS $$
BEGIN
     INSERT INTO tags (label, description) 
         VALUES ('', NULL);
     RETURN currval('tags_id_seq');
END;
$$ ;

REVOKE ALL ON FUNCTION create_tag_ds() 
                FROM PUBLIC;
GRANT EXECUTE ON FUNCTION create_tag_ds() 
                TO GROUP :admin_group;

CREATE TRIGGER t1_nm_tags_cases_insert AFTER
    INSERT ON nm_tags_cases
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_nm_tags_cases_update AFTER
    UPDATE ON nm_tags_cases
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();

CREATE TRIGGER t1_nm_tags_cases_delete AFTER
    DELETE ON nm_tags_cases
    FOR EACH ROW EXECUTE PROCEDURE rg_lastaccess_log();


INSERT INTO db_history (beschreibung, zeitpunkt)
        VALUES ('1.0/tags.sql', current_timestamp);

CREATE OR REPLACE FUNCTION waska_tag() RETURNS TRIGGER AS $$
BEGIN
    IF TG_OP = 'DELETE' THEN
        RETURN OLD;
    ELSE
    	PERFORM check_case(NEW.id);
        RETURN NEW;
    END IF;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER t_master_tbl_insert_check AFTER
    INSERT ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE waska_tag(); 

CREATE TRIGGER t_master_tbl_update_check AFTER
    UPDATE ON master_tbl
    FOR EACH ROW EXECUTE PROCEDURE waska_tag();

COMMIT;
