BEGIN;

-- 
-- Repeat Group fuer Elternarbeit
-- 

ALTER TABLE master_tbl DISABLE TRIGGER USER;


SET ROLE :db_adm;

INSERT INTO db_history (beschreibung, zeitpunkt)
       VALUES ('2.0/07_rg_elternarbeit.sql', current_timestamp);


-- Create a new function to generate RG-entries.
-- This is the original function, without the DS IS check and exception
CREATE OR REPLACE FUNCTION create_rg_elternarbeit_tbl(pid integer, nuuid char(36))
RETURNS integer
LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER AS
$$
DECLARE
    rid integer;
    mid integer;
BEGIN
    mid := pid;

    IF NOT isEditorOrStandin(mid) THEN
        -- RAISE EXCEPTION 'DS ID not session_user ID';
    END IF;

    INSERT INTO rg_elternarbeit_tbl (master_id) VALUES (pid);

    SELECT INTO rid currval('rg_elternarbeit_tbl_id_seq');

    IF nuuid IS NOT NULL THEN
        UPDATE rg_elternarbeit_tbl
        SET    uuid_id = nuuid
        WHERE  id = rid;
    ELSE
        PERFORM set_uuid('rg_elternarbeit_tbl', rid);
        
    END IF;

    RETURN rid;
END;
$$;



-- Uebernahme der alten Eintraege in eine Repeat Group
--
-- Fuer alle Eintrage in der master_tbl
CREATE OR REPLACE FUNCTION insert_rg() RETURNS VOID AS $$
DECLARE
  r RECORD;
  rgid INTEGER;
  rg_count INTEGER;
  uuid TEXT;
BEGIN
  FOR r in SELECT *
  FROM master_tbl LOOP
  
      -- Zunaechst alle RGs loeschen
      DELETE from rg_elternarbeit_tbl WHERE master_id = r.id;

      -- elt_ziel_a -> Thema: "Foerderung von Erziehungskompetenzen", ID: 1
      IF r.elt_ziel_a != -1
         OR r.elt_zerr_a != -1
	 OR r.elt_sf_a IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_elternarbeit_tbl(r.id, uuid);
            UPDATE rg_elternarbeit_tbl set
	       elternarbeit_thema = 1,
               elternarbeit_ziel = r.elt_ziel_a,
               elternarbeit_ziel_erreicht = r.elt_zerr_a,
               elternarbeit_schlussfolgerungen = r.elt_sf_a
            WHERE id = rgid;
      END IF;

      
      -- elt_ziel_b -> Thema: "Foerderung der Beziehung zwischen Kind und Eltern", ID: 2
      IF r.elt_ziel_b != -1
         OR r.elt_zerr_b != -1
	 OR r.elt_sf_b IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_elternarbeit_tbl(r.id, uuid);
            UPDATE rg_elternarbeit_tbl set
	       elternarbeit_thema = 2,
               elternarbeit_ziel = r.elt_ziel_b,
               elternarbeit_ziel_erreicht = r.elt_zerr_b,
               elternarbeit_schlussfolgerungen = r.elt_sf_b
            WHERE id = rgid;
      END IF;

      -- elt_ziel_c -> Thema: "Foerderung von Alltagsbewaeltigungskompetenz", ID: 3
      IF r.elt_ziel_c != -1
         OR r.elt_zerr_c != -1
	 OR r.elt_sf_c IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_elternarbeit_tbl(r.id, uuid);
            UPDATE rg_elternarbeit_tbl set
	       elternarbeit_thema = 3,
               elternarbeit_ziel = r.elt_ziel_c,
               elternarbeit_ziel_erreicht = r.elt_zerr_c,
               elternarbeit_schlussfolgerungen = r.elt_sf_c
            WHERE id = rgid;
      END IF;

      -- elt_ziel_d -> Thema: "Abbau von innerfamiliaerer Gewalt", ID: 4
      IF r.elt_ziel_d != -1
         OR r.elt_zerr_d != -1
	 OR r.elt_sf_d IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_elternarbeit_tbl(r.id, uuid);
            UPDATE rg_elternarbeit_tbl set
	       elternarbeit_thema = 4,
               elternarbeit_ziel = r.elt_ziel_d,
               elternarbeit_ziel_erreicht = r.elt_zerr_d,
               elternarbeit_schlussfolgerungen = r.elt_sf_d
            WHERE id = rgid;
      END IF;

      -- elt_ziel_e -> Thema: "Foerderung des Bezugs der Eltern zur Schule", ID: 5
      IF r.elt_ziel_e != -1
         OR r.elt_zerr_e != -1
	 OR r.elt_sf_e IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_elternarbeit_tbl(r.id, uuid);
            UPDATE rg_elternarbeit_tbl set
	       elternarbeit_thema = 5,
               elternarbeit_ziel = r.elt_ziel_e,
               elternarbeit_ziel_erreicht = r.elt_zerr_e,
               elternarbeit_schlussfolgerungen = r.elt_sf_e
            WHERE id = rgid;
      END IF;

      -- elt_ziel_f -> Thema: "Foerderung der schulischen
      -- Unterstuetzungskompetenzen der Eltern", ID: 6
      IF r.elt_ziel_f != -1
         OR r.elt_zerr_f != -1
	 OR r.elt_sf_f IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_elternarbeit_tbl(r.id, uuid);
            UPDATE rg_elternarbeit_tbl set
	       elternarbeit_thema = 6,
               elternarbeit_ziel = r.elt_ziel_f,
               elternarbeit_ziel_erreicht = r.elt_zerr_f,
               elternarbeit_schlussfolgerungen = r.elt_sf_f
            WHERE id = rgid;
      END IF;

      -- elt_ziel_g -> Thema: "Abbau von Verschuldung", ID: 7
      IF r.elt_ziel_g != -1
         OR r.elt_zerr_g != -1
	 OR r.elt_sf_g IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_elternarbeit_tbl(r.id, uuid);
            UPDATE rg_elternarbeit_tbl set
	       elternarbeit_thema = 7,
               elternarbeit_ziel = r.elt_ziel_g,
               elternarbeit_ziel_erreicht = r.elt_zerr_g,
               elternarbeit_schlussfolgerungen = r.elt_sf_g
            WHERE id = rgid;
      END IF;
      
      -- elt_ziel_h -> Thema: "Vermittlung an weitere Hilfeinstitutionen", ID: 8
      IF r.elt_ziel_h != -1
         OR r.elt_zerr_h != -1
	 OR r.elt_sf_h IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_elternarbeit_tbl(r.id, uuid);
            UPDATE rg_elternarbeit_tbl set
	       elternarbeit_thema = 8,
               elternarbeit_ziel = r.elt_ziel_h,
               elternarbeit_ziel_erreicht = r.elt_zerr_h,
               elternarbeit_schlussfolgerungen = r.elt_sf_h
            WHERE id = rgid;
      END IF;
      
      -- elt_ziel_i -> Thema: "Sonstiges", ID: -2
      IF r.elt_ziel_i != -1
         OR r.elt_zerr_i != -1
	 OR r.elt_sf_i IS NOT NULL
         OR r.elt_ziel_i_t IS NOT NULL THEN
	    uuid = generate_uuidgen();
            rgid = create_rg_elternarbeit_tbl(r.id, uuid);
            UPDATE rg_elternarbeit_tbl set
	       elternarbeit_thema = -2,
               elternarbeit_ziel = r.elt_ziel_i,
               elternarbeit_ziel_erreicht = r.elt_zerr_i,
               elternarbeit_schlussfolgerungen = r.elt_sf_i,
	       elternarbeit_sonstiges = r.elt_ziel_i_t
            WHERE id = rgid;
      END IF;

      -- Falls keine RGs angelegt wurden, eine neue erstellen
      SELECT COUNT(id) INTO rg_count FROM rg_elternarbeit_tbl WHERE master_id  = r.id;
      IF rg_count = 0 THEN
      	uuid = generate_uuidgen();
        rgid = create_rg_elternarbeit_tbl(r.id, uuid);
      END IF;

  END LOOP;
END;
$$ LANGUAGE plpgsql;
SET ROLE postgres;
SELECT insert_rg();
SET ROLE :db_adm;
DROP FUNCTION insert_rg();




-- Restore old function with its corresponding exception
CREATE OR REPLACE FUNCTION create_rg_elternarbeit_tbl(pid integer, nuuid char(36))
RETURNS integer
LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER AS
$$
DECLARE
    rid integer;
    mid integer;
BEGIN
    mid := pid;

    IF NOT isEditorOrStandin(mid) THEN
        RAISE EXCEPTION 'DS ID not session_user ID';
    END IF;

    INSERT INTO rg_elternarbeit_tbl (master_id) VALUES (pid);

    SELECT INTO rid currval('rg_elternarbeit_tbl_id_seq');

    IF nuuid IS NOT NULL THEN
        UPDATE rg_elternarbeit_tbl
        SET    uuid_id = nuuid
        WHERE  id = rid;
    ELSE
        PERFORM set_uuid('rg_elternarbeit_tbl', rid);
        
    END IF;

    RETURN rid;
END;
$$;



SET ROLE postgres;
ALTER TABLE master_tbl ENABLE TRIGGER USER;

-- ROLLBACK;
COMMIT;
