#!/bin/sh
#set -x

CMD=${1}

DB_IDENTIFIER=${2}
DB="ka_${DB_IDENTIFIER}_db"
PORT=${3:-5432}
DIR_PREFIX="."
ROLES="roles.sql"
TYP="waska"

EXPORT_CMD="pg_dump -a -d --attribute-inserts -t" 
IMPORT_CMD="psql --single-transaction -f " 

PRE_1=" ka_benutzergruppe_tbl ka_benutzer_tbl nm_benutzer_gruppe_tbl"
PRE_2="db_history dbinfo ka_konfiguration_tbl ka_nachrichten_art_tbl ka_nachrichten_tbl nm_benutzer_nachrichten_tbl"

MASTER="master_tbl"

POST_1="nm_benutzer_master_tbl ka_status_tbl"
POST_2="ka_dokumente_tbl ka_termine_tbl ka_logbuch_tbl"

EXPORT_ALL="${PRE_1} ${PRE_2} ${MASTER} ${POST_1} ${POST_2}"
IMPORT_ALL="${PRE_1} ${PRE_2} ${MASTER} ${POST_1} ${POST_2}"

#DISABLE_TRIGGERS="ka_benutzergruppe_tbl ka_benutzer_tbl master_tbl ka_status_tbl"
DISABLE_TRIGGERS=${IMPORT_ALL}

DST_DIR=${DIR_PREFIX}/${DB}

update_structure_tbl () {
    exit 0
}

# Check if there is a file with all usercredentionals of the old cluster. This
# will will be used on restoring data to get the user credentionals
if ! [ -e ${ROLES} ]; then
    echo "File ${ROLES} not found!"
    exit 1
fi

# 
# EXPORT
#
if [ ${CMD} = "export" ]; then
    # 1. Create subdir for all dumps of current db
    mkdir ${DST_DIR}
    # 2. Dump all datatables. Each table will be in a seperate file.  
    for tbls in ${EXPORT_ALL}
    do
        for tbl in ${tbls}
        do
            if ! ${EXPORT_CMD} ${tbl} ${DB} -p ${PORT} > ${DST_DIR}/${tbl}.sql;
                then
                    echo "Fehler beim Exportieren der Tabelle ${tbl} in ${DB}" >> ${DST_DIR}/export_log.txt 2>&1;
                    exit 1
            fi
            if [ ${tbl} == 'ka_benutzer_tbl' ]; then
               sed -i -e "s/${DB_IDENTIFIER}_\(admin\|cm\|pb\)'/${DB_IDENTIFIER}_\1_kennung'/g" ${DST_DIR}/${tbl}.sql
            fi
        done
    done

    # 2. Dump user credentials 
    REGEXP1="s/${TYP}_role_adm/mpuls_role_adm/g"
    REGEXP2="^CREATE.*${DB_IDENTIFIER}\(_adm\|_admin\|_cm\|_pb\);$"
    REGEXP3="^ALTER.*${DB_IDENTIFIER}\(_admin\|_cm\|_pb\).*;$"
    REGEXP4="s/ka_${DB_IDENTIFIER}_\(admin\|cm\|pb\)_ka/ka_${DB_IDENTIFIER}_\1/g"
    REGEXP5="ka_${DB_IDENTIFIER}_\(adm\|admin\|cm\|pb\) GRANTED"
    REGEXP6="s/^.*\ka_${DB_IDENTIFIER}_\(.*\);/GRANT CONNECT ON DATABASE ka_${DB_IDENTIFIER}_db TO ka_${DB_IDENTIFIER}_\1;/g"

    REGEXP7="s/ka_${DB_IDENTIFIER}_admin;/ka_${DB_IDENTIFIER}_admin_kennung;/g"
    REGEXP8="s/ka_${DB_IDENTIFIER}_cm;/ka_${DB_IDENTIFIER}_cm_kennung;/g"
    REGEXP9="s/ka_${DB_IDENTIFIER}_pb;/ka_${DB_IDENTIFIER}_pb_kennung;/g"

    # a) Retain logins named _admin, _cm, _pb with additional _kennung suffix to
    # avoid naming conflicts with system roles admin, cm, and pb
    # b) Ignore creating and altering old systemroles _admin_ka, cm_ka and pb_ka
    # c) Rename old GRANTS related to the old rolenames _admin_ka, _cm_ka and _pb_ka
    # d) Ignore membership of new system roles.
    # e) Rename system intern waska-roles into mpuls-roles.
    echo "BEGIN;" > ${DST_DIR}/roles.sql
    grep "ka_${DB_IDENTIFIER}" ${ROLES} \
    | grep -v -e ${REGEXP2} \
    | grep -v -e ${REGEXP3} \
    | sed -e "${REGEXP7}" \
    | sed -e "${REGEXP8}" \
    | sed -e "${REGEXP9}" \
    | sed -e ${REGEXP4} \
    | sed -e ${REGEXP1} \
    | grep -v -e "${REGEXP5}" \
    > ${DST_DIR}/roles_create.sql
    
    # Grant connect to the roles.
    # a) Grant connect privileges based on created users. 
    grep 'CREATE ROLE' ${DST_DIR}/roles_create.sql \
    | sed -e "${REGEXP6}" \
    > ${DST_DIR}/roles_connect.sql
    # Comine role creation and connect grants
    cat ${DST_DIR}/roles_create.sql ${DST_DIR}/roles_connect.sql \
    >> ${DST_DIR}/roles.sql
    echo "--ROLLBACK;" >> ${DST_DIR}/roles.sql
    echo "COMMIT;" >> ${DST_DIR}/roles.sql
    echo "Export successfull for ${DB}" >> ${DST_DIR}/export_log.txt 2>&1
fi

# 
# IMPORT 
#
# For importing you need to be in the directory containing the data_dumps files
# created by the export.
if [ ${CMD} = "import" ]; then
    
    # Create new logfile
    echo "" > import_log.log 

    # Temporaere Datei mit allen Tabellen
    if [ -e tables.txt ]; then
    	rm tables.txt
    fi
    for tbls in ${IMPORT_ALL}
    do
        for tbl in ${tbls}
        do
        	echo ${tbl} >> tables.txt
        done
    done

    echo "Importing data..."
    # For each table
    for tbl in `tac tables.txt`
    do
        echo "-- Deleting old entries ${tbl}" > tmp.sql
        echo "DELETE FROM ${tbl}" >> tmp.sql

        # Delete data in a single transaction.
        ${IMPORT_CMD} tmp.sql -p ${PORT} -d ${DB} >> import_log.log 2>&1

        # Check if table is restored succsessfull 
        egrep -m 1 -A 5 '(ERROR|FEHLER)' import_log.log
        if [ $? -eq 0 ]; then
            echo "Fehler beim Loeschen von Daten in der Tabelle ${tbl} in ${DB}\n";
            echo "See logfile with 'less ${DB}.sql'"
            exit 1
        fi
        # Remove tmp sql file
        rm tmp.sql
    done

    for tbl in `cat tables.txt` 
    do
        # Create a temporay file by appending all needed sql-statements for
        # importing the current table 
        echo "-- Importing ${tbl}" > tmp.sql

        #
        # TRIGGERS (Disable)
        #
        # Add disable triggers
        # Check if the triggers should stay disabled while importing the data
        # This is usefull to not trigger updates on the ka status_tbl eg.
        for dt in ${DISABLE_TRIGGERS}
        do
            if [ ${dt} == ${tbl} ]; then
    	    # Only disable Usertrigger, not foreign key constraints.
                echo "ALTER TABLE ${tbl} DISABLE TRIGGER USER;" >> tmp.sql
            fi
        done

        #
        # Import
        #

        # Add deleting old entries in the table
        echo "DELETE FROM ${tbl};" >> tmp.sql

        # Add data
        if [ -e ${tbl}.sql ]; then
            cat ${tbl}.sql >> tmp.sql
        else
            echo "Warning: table ${tbl} not found"
        fi 

        # Finally restor data. Restoring data is done in a single transaction.
        ${IMPORT_CMD} tmp.sql  -p ${PORT} -d ${DB} >> import_log.log 2>&1

        # Check if table is restored succsessfull 
        egrep -m 1 -A 5 '(ERROR|FEHLER)' import_log.log
        if [ $? -eq 0 ]; then
            echo "Fehler beim Importieren der Tabelle ${tbl} in ${DB}\n";
            echo "See logfile with 'less ${DB}.sql'"
            exit 1
        fi
        # Remove tmp sql file
        rm tmp.sql

        #
        # TRIGGERS (Re-Enable)
        #
        # Reenabling triggers
        echo "-- Reenabling triggers" > tmp.sql
        echo "ALTER TABLE ${tbl} ENABLE TRIGGER USER;"> tmp.sql
        # Reenable sql 
        ${IMPORT_CMD} tmp.sql  -p ${PORT} -d ${DB} >> import_log.log 2>&1

        # Check if table is restored succsessfull 
        egrep -m 1 -A 5 '(ERROR|FEHLER)' import_log.log
        if [ $? -eq 0 ]; then
            echo "Fehler beim Import der Tabelle ${tbl} in ${DB}\n";
            echo "See logfile with 'less ${DB}.sql'"
            exit 1
        fi
        # Remove tmp sql file
        rm tmp.sql
    done
    

    # 2. Build casestructure
    echo "Rebuilding casestructure..."
    echo "delete from case_structure; select create_structure();" > tmp.sql
    ${IMPORT_CMD} tmp.sql  -p ${PORT} -d ${DB} >> import_log.log 2>&1
    # Check if table is restored succsessfull 
    egrep -m 1 -A 5 '(ERROR|FEHLER)' import_log.log
    if [ $? -eq 0 ]; then
        echo "Fehler beim Import der Tabelle ${tbl} in ${DB}\n";
        echo "See logfile with 'less ${DB}.sql'"
        exit 1
    fi
    # Remove tmp sql file
    rm tmp.sql


fi

if [ ${CMD} = "roles" ]; then 
    ## 3. Restore user credentials
    echo "Restoring usercredentials..."
    #${IMPORT_CMD} roles.sql  -p ${PORT} -d ${DB} >> roles_log.log 2>&1
    psql -f roles.sql  -p ${PORT} -d ${DB} > roles_log.log 2>&1
    egrep -m 1 -A 5 '(ERROR|FEHLER)' roles_log.log
    if [ $? -eq 0 ]; then
        echo "Fehler beim Importieren der rollen in ${DB}\n";
        echo "See logfile with 'less roles_log.log'"
        exit 1
    fi
    echo "Import successfull for ${DB}"
    exit 0
fi
