# -*- coding: utf-8 -*-
# Copyright 2007, 2008 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls WASKA (CoMPUter-based case fiLeS -
# Web-Anwendungs-Server fuer Kompetenzagenturen).
#
# mpuls WASKA is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls WASKA is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls WASKA. If not, see <http://www.gnu.org/licenses/>.
#
# mpuls WASKA has been developed on behalf of the
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and
# European Social Fund resources.

from formencode import ForEach
from formencode.validators import Bool, String, Int, DateValidator
from mpulsweb.lib.validators import BaseFormValidator, DateCheck, KeineAngabe, \
     DateOrder, MyDateConverter, TimeDeltaCheck

class NewCaseForm(BaseFormValidator):

    name = String()
    vorname = String()
    addresse_strasse_1 = String()
    addresse_strassenr_1 = String()
    addresse_plz_1 = String()
    addresse_ort_1 = String()
    aufnahme_typ     = Int(if_missing=0)
    statement_signed = Bool(if_missing=False)

class PermissionForm(BaseFormValidator):
    userid = ForEach(String(), convert_to_list=True)

class ExtraTimeFormValidator1(BaseFormValidator):

    allow_extra_fields = True
    filter_extra_fields = True

    cm_datum_verlaengerung_1 = DateCheck(not_empty=True)
    cm_bestaet_verlaengerung_1 = String(if_missing="")
    cm_anmerk_verlaengerung_1 = String()


class ExtraTimeFormValidator2(BaseFormValidator):

    allow_extra_fields = True
    filter_extra_fields = True

    # Data from first extratime. Needed here to be available in errorcase for
    # htmlfill
    cm_datum_verlaengerung_1 = DateCheck(not_empty=True)
    cm_bestaet_verlaengerung_1 = String(if_missing="")
    cm_anmerk_verlaengerung_1 = String()

    cm_datum_verlaengerung_2 = DateCheck(not_empty=True)
    cm_bestaet_verlaengerung_2 = String(if_missing="")
    cm_anmerk_verlaengerung_2 = String()


class RenewFormValidator(BaseFormValidator):

    allow_extra_fields = True
    filter_extra_fields = True

    cm_neuauf_genehm = String()
    cm2c_t = String(not_empty=True)


class ReopenFormValidator1(BaseFormValidator):

    allow_extra_fields = True
    filter_extra_fields = True

    cm_wiederauf_genehm_1 = String()
    # Konvertierung in datetime-objekte.
    datum_cm_ende = MyDateConverter(not_empty=True, month_style='dd.mm.jjjj')
    cm_wiederauf_genehm_datum_1 = MyDateConverter(not_empty=True, month_style='dd.mm.jjjj')
    cm_wiederauf_datum_bis_1 = MyDateConverter(not_empty=True, month_style='dd.mm.jjjj')

    #cm_wiederauf_genehm_datum_1 = DateCheck(not_empty=True) 
    #cm_wiederauf_datum_bis_1 = DateCheck(not_empty=True) 

    # Diese Validatoren greifen nur auf die übermittelten Werte in dem request
    # zu, also nicht dem entsprec enden python typen nach einer Validierung
    chained_validators = [
        DateOrder('datum_cm_ende', 'cm_wiederauf_genehm_datum_1'),
        DateOrder('cm_wiederauf_genehm_datum_1', 'cm_wiederauf_datum_bis_1'),
        TimeDeltaCheck('cm_wiederauf_genehm_datum_1', 'cm_wiederauf_datum_bis_1', days=93)
    ]
    cm2c_t = String(not_empty=True)


class ReopenFormValidator1abgel(BaseFormValidator):

    allow_extra_fields = True
    filter_extra_fields = True

    cm_wiederauf_genehm_1 = String()
    cm_wiederauf_genehm_datum_1 = String()
    cm_wiederauf_datum_bis_1 = String()
    cm2c_t = String()


class ReopenFormValidator2(BaseFormValidator):

    allow_extra_fields = True
    filter_extra_fields = True

    cm_wiederauf_genehm_2 = String()
    cm_wiederauf_datum_bis_2 = DateCheck(not_empty=True)
    cm2c_t = String()
    cm2c_t2 = String(not_empty=True)


class ReopenFormValidator2abgel(BaseFormValidator):

    allow_extra_fields = True
    filter_extra_fields = True

    cm_wiederauf_genehm_2 = String()
    cm_wiederauf_datum_bis_2 = String()
    cm2c_t = String()


class WiederaufnahmeCaseForm(BaseFormValidator):

    cm_dok_datum_beendigung = MyDateConverter(not_empty=True, month_style='dd.mm.jjjj')
    cm_dok_end_verm = String()
    cm_wiederauf_genehm_datum_1 = MyDateConverter(not_empty=True, month_style='dd.mm.jjjj')
    cm_wiederauf_datum_bis_1 = MyDateConverter(not_empty=True, month_style='dd.mm.jjjj')
    cm2c_t = String(not_empty=True)
    cm_dok_end_verm = KeineAngabe()
    chained_validators = [
        DateOrder('cm_dok_datum_beendigung', 'cm_wiederauf_genehm_datum_1'),
        DateOrder('cm_wiederauf_genehm_datum_1', 'cm_wiederauf_datum_bis_1'),
        TimeDeltaCheck('cm_wiederauf_genehm_datum_1', 'cm_wiederauf_datum_bis_1', days=93)
    ]

class NeuaufnahmeCaseForm(BaseFormValidator):

    cm_dok_datum_beendigung = DateCheck(not_empty=True)
    cm_dok_end_sonst = KeineAngabe()
    cm2c_t = String(not_empty=True)

# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8
